# Settings

Table 1. Quick reference for section “general”
Setting | Description
--- | ---
ignore-case | Whether to find text on a page case-insensitively.
startpage | The default page(s) to open at the start, separated by commas.
default-page | The page to open if :open -t/-b/-w is used without URL. Use `about:blank` for a blank page.
auto-search | Whether to start a search when something else than a URL is entered.
auto-save-config | Whether to save the config automatically on quit.
auto-save-interval | How often (in milliseconds) to auto-save config/cookies/etc.
editor | The editor (and arguments) to use for the `open-editor` command.
editor-encoding | Encoding to use for editor.
private-browsing | Do not record visited pages in the history or store web page icons.
developer-extras | Enable extra tools for Web developers.
print-element-backgrounds | Whether the background color and images are also drawn when the page is printed.
xss-auditing | Whether load requests should be monitored for cross-site scripting attempts.
site-specific-quirks | Enable workarounds for broken sites.
default-encoding | Default encoding to use for websites.
new-instance-open-target | How to open links in an existing instance if a new one is launched.
log-javascript-console | How to log javascript console messages.
save-session | Whether to always save the open pages.
session-default-name | The name of the session to save by default, or empty for the last loaded session.
url-incdec-segments | The URL segments where `:navigate increment/decrement` will search for a number.

Table 2. Quick reference for section “ui”
Setting | Description
--- | ---
zoom-levels | The available zoom levels, separated by commas.
default-zoom | The default zoom level.
downloads-position | Where to show the downloaded files.
status-position | The position of the status bar.
message-timeout | Time (in ms) to show messages in the statusbar for.
message-unfocused | Whether to show messages in unfocused windows.
confirm-quit | Whether to confirm quitting the application.
zoom-text-only | Whether the zoom factor on a frame applies only to the text or to all content.
frame-flattening | Whether to expand each subframe to its contents.
user-stylesheet | User stylesheet to use (absolute filename, filename relative to the config directory or CSS string). Will expand environment variables.
css-media-type | Set the CSS media type.
smooth-scrolling | Whether to enable smooth scrolling for webpages.
remove-finished-downloads | Number of milliseconds to wait before removing finished downloads. Will not be removed if value is -1.
hide-statusbar | Whether to hide the statusbar unless a message is shown.
statusbar-padding | Padding for statusbar (top, bottom, left, right).
window-title-format | The format to use for the window title. The following placeholders are defined:
hide-mouse-cursor | Whether to hide the mouse cursor.
modal-js-dialog | Use standard JavaScript modal dialog for alert() and confirm()
hide-wayland-decoration | Hide the window decoration when using wayland (requires restart)
keyhint-blacklist | Keychains that shouldn’t be shown in the keyhint dialog

Table 3. Quick reference for section “network”
Setting | Description
--- | ---
do-not-track | Value to send in the `DNT` header.
accept-language | Value to send in the `accept-language` header.
referer-header | Send the Referer header
user-agent | User agent to send. Empty to send the default.
proxy | The proxy to use.
proxy-dns-requests | Whether to send DNS requests over the configured proxy.
ssl-strict | Whether to validate SSL handshakes.
dns-prefetch | Whether to try to pre-fetch DNS entries to speed up browsing.
custom-headers | Set custom headers for qutebrowser HTTP requests.

Table 4. Quick reference for section “completion”
Setting | Description
--- | ---
auto-open | Automatically open completion when typing.
download-path-suggestion | What to display in the download filename input.
timestamp-format | How to format timestamps (e.g. for history)
show | Whether to show the autocompletion window.
height | The height of the completion, in px or as percentage of the window.
cmd-history-max-items | How many commands to save in the command history.
web-history-max-items | How many URLs to show in the web history.
quick-complete | Whether to move on to the next part when there’s only one possible completion left.
shrink | Whether to shrink the completion to be smaller than the configured size if there are no scrollbars.
scrollbar-width | Width of the scrollbar in the completion window (in px).
scrollbar-padding | Padding of scrollbar handle in completion window (in px).

Table 5. Quick reference for section “input”
Setting | Description
--- | ---
timeout | Timeout for ambiguous key bindings.
partial-timeout | Timeout for partially typed key bindings.
insert-mode-on-plugins | Whether to switch to insert mode when clicking flash and other plugins.
auto-leave-insert-mode | Whether to leave insert mode if a non-editable element is clicked.
auto-insert-mode | Whether to automatically enter insert mode if an editable element is focused after page load.
forward-unbound-keys | Whether to forward unbound keys to the webview in normal mode.
spatial-navigation | Enables or disables the Spatial Navigation feature.
links-included-in-focus-chain | Whether hyperlinks should be included in the keyboard focus chain.
rocker-gestures | Whether to enable Opera-like mouse rocker gestures. This disables the context menu.
mouse-zoom-divider | How much to divide the mouse wheel movements to translate them into zoom increments.

Table 6. Quick reference for section “tabs”
Setting | Description
--- | ---
background-tabs | Whether to open new tabs (middleclick/ctrl+click) in background.
select-on-remove | Which tab to select when the focused tab is removed.
new-tab-position | How new tabs are positioned.
new-tab-position-explicit | How new tabs opened explicitly are positioned.
last-close | Behavior when the last tab is closed.
show | When to show the tab bar
show-switching-delay | Time to show the tab bar before hiding it when tabs→show is set to switching.
wrap | Whether to wrap when changing tabs.
movable | Whether tabs should be movable.
close-mouse-button | On which mouse button to close tabs.
position | The position of the tab bar.
show-favicons | Whether to show favicons in the tab bar.
width | The width of the tab bar if it’s vertical, in px or as percentage of the window.
indicator-width | Width of the progress indicator (0 to disable).
tabs-are-windows | Whether to open windows instead of tabs.
title-format | The format to use for the tab title. The following placeholders are defined:
title-alignment | Alignment of the text inside of tabs
mousewheel-tab-switching | Switch between tabs using the mouse wheel.
padding | Padding for tabs (top, bottom, left, right).
indicator-padding | Padding for indicators (top, bottom, left, right).

Table 7. Quick reference for section “storage”
Setting | Description
--- | ---
download-directory | The directory to save downloads to. An empty value selects a sensible os-specific default. Will expand environment variables.
prompt-download-directory | Whether to prompt the user for the download location.
remember-download-directory | Whether to remember the last used download directory.
maximum-pages-in-cache | The maximum number of pages to hold in the global memory page cache.
object-cache-capacities | The capacities for the global memory cache for dead objects such as stylesheets or scripts. Syntax: cacheMinDeadCapacity, cacheMaxDead, totalCapacity.
offline-storage-default-quota | Default quota for new offline storage databases.
offline-web-application-cache-quota | Quota for the offline web application cache.
offline-storage-database | Whether support for the HTML 5 offline storage feature is enabled.
offline-web-application-storage | Whether support for the HTML 5 web application cache feature is enabled.
local-storage | Whether support for the HTML 5 local storage feature is enabled.
cache-size | Size of the HTTP network cache.

Table 8. Quick reference for section “content”
Setting | Description
--- | ---
allow-images | Whether images are automatically loaded in web pages.
allow-javascript | Enables or disables the running of JavaScript programs.
allow-plugins | Enables or disables plugins in Web pages.
webgl | Enables or disables WebGL.
css-regions | Enable or disable support for CSS regions.
hyperlink-auditing | Enable or disable hyperlink auditing (<a ping>).
geolocation | Allow websites to request geolocations.
notifications | Allow websites to show notifications.
javascript-can-open-windows | Whether JavaScript programs can open new windows.
javascript-can-close-windows | Whether JavaScript programs can close windows.
javascript-can-access-clipboard | Whether JavaScript programs can read or write to the clipboard.
ignore-javascript-prompt | Whether all javascript prompts should be ignored.
ignore-javascript-alert | Whether all javascript alerts should be ignored.
local-content-can-access-remote-urls | Whether locally loaded documents are allowed to access remote urls.
local-content-can-access-file-urls | Whether locally loaded documents are allowed to access other local urls.
cookies-accept | Control which cookies to accept.
cookies-store | Whether to store cookies.
host-block-lists | List of URLs of lists which contain hosts to block.
host-blocking-enabled | Whether host blocking is enabled.
host-blocking-whitelist | List of domains that should always be loaded, despite being ad-blocked.
enable-pdfjs | Enable pdf.js to view PDF files in the browser.

Table 9. Quick reference for section “hints”
Setting | Description
--- | ---
border | CSS border value for hints.
opacity | Opacity for hints.
mode | Mode to use for hints.
chars | Chars used for hint strings.
min-chars | Minimum number of chars used for hint strings.
scatter | Whether to scatter hint key chains (like Vimium) or not (like dwb). Ignored for number hints.
uppercase | Make chars in hint strings uppercase.
dictionary | The dictionary file to be used by the word hints.
auto-follow | Follow a hint immediately when the hint text is completely matched.
auto-follow-timeout | A timeout to inhibit normal-mode key bindings after a successfulauto-follow.
next-regexes | A comma-separated list of regexes to use for next links.
prev-regexes | A comma-separated list of regexes to use for prev links.
find-implementation | Which implementation to use to find elements to hint.

Table 10. Quick reference for section “colors”
Setting | Description
--- | ---
completion.fg | Text color of the completion widget.
completion.bg | Background color of the completion widget.
completion.alternate-bg | Alternating background color of the completion widget.
completion.category.fg | Foreground color of completion widget category headers.
completion.category.bg | Background color of the completion widget category headers.
completion.category.border.top | Top border color of the completion widget category headers.
completion.category.border.bottom | Bottom border color of the completion widget category headers.
completion.item.selected.fg | Foreground color of the selected completion item.
completion.item.selected.bg | Background color of the selected completion item.
completion.item.selected.border.top | Top border color of the completion widget category headers.
completion.item.selected.border.bottom | Bottom border color of the selected completion item.
completion.match.fg | Foreground color of the matched text in the completion.
completion.scrollbar.fg | Color of the scrollbar handle in completion view.
completion.scrollbar.bg | Color of the scrollbar in completion view
statusbar.fg | Foreground color of the statusbar.
statusbar.bg | Background color of the statusbar.
statusbar.fg.error | Foreground color of the statusbar if there was an error.
statusbar.bg.error | Background color of the statusbar if there was an error.
statusbar.fg.warning | Foreground color of the statusbar if there is a warning.
statusbar.bg.warning | Background color of the statusbar if there is a warning.
statusbar.fg.prompt | Foreground color of the statusbar if there is a prompt.
statusbar.bg.prompt | Background color of the statusbar if there is a prompt.
statusbar.fg.insert | Foreground color of the statusbar in insert mode.
statusbar.bg.insert | Background color of the statusbar in insert mode.
statusbar.fg.command | Foreground color of the statusbar in command mode.
statusbar.bg.command | Background color of the statusbar in command mode.
statusbar.fg.caret | Foreground color of the statusbar in caret mode.
statusbar.bg.caret | Background color of the statusbar in caret mode.
statusbar.fg.caret-selection | Foreground color of the statusbar in caret mode with a selection
statusbar.bg.caret-selection | Background color of the statusbar in caret mode with a selection
statusbar.progress.bg | Background color of the progress bar.
statusbar.url.fg | Default foreground color of the URL in the statusbar.
statusbar.url.fg.success | Foreground color of the URL in the statusbar on successful load (http).
statusbar.url.fg.success.https | Foreground color of the URL in the statusbar on successful load (https).
statusbar.url.fg.error | Foreground color of the URL in the statusbar on error.
statusbar.url.fg.warn | Foreground color of the URL in the statusbar when there’s a warning.
statusbar.url.fg.hover | Foreground color of the URL in the statusbar for hovered links.
tabs.fg.odd | Foreground color of unselected odd tabs.
tabs.bg.odd | Background color of unselected odd tabs.
tabs.fg.even | Foreground color of unselected even tabs.
tabs.bg.even | Background color of unselected even tabs.
tabs.fg.selected.odd | Foreground color of selected odd tabs.
tabs.bg.selected.odd | Background color of selected odd tabs.
tabs.fg.selected.even | Foreground color of selected even tabs.
tabs.bg.selected.even | Background color of selected even tabs.
tabs.bg.bar | Background color of the tab bar.
tabs.indicator.start | Color gradient start for the tab indicator.
tabs.indicator.stop | Color gradient end for the tab indicator.
tabs.indicator.error | Color for the tab indicator on errors..
tabs.indicator.system | Color gradient interpolation system for the tab indicator.
hints.fg | Font color for hints.
hints.bg | Background color for hints.
hints.fg.match | Font color for the matched part of hints.
downloads.bg.bar | Background color for the download bar.
downloads.fg.start | Color gradient start for download text.
downloads.bg.start | Color gradient start for download backgrounds.
downloads.fg.stop | Color gradient end for download text.
downloads.bg.stop | Color gradient stop for download backgrounds.
downloads.fg.system | Color gradient interpolation system for download text.
downloads.bg.system | Color gradient interpolation system for download backgrounds.
downloads.fg.error | Foreground color for downloads with errors.
downloads.bg.error | Background color for downloads with errors.
webpage.bg | Background color for webpages if unset (or empty to use the theme’s color)
keyhint.fg | Text color for the keyhint widget.
keyhint.fg.suffix | Highlight color for keys to complete the current keychain
keyhint.bg | Background color of the keyhint widget.

Table 11. Quick reference for section “fonts”
Setting | Description
--- | ---
_monospace | Default monospace fonts.
completion | Font used in the completion widget.
tabbar | Font used in the tab bar.
statusbar | Font used in the statusbar.
downloads | Font used for the downloadbar.
hints | Font used for the hints.
debug-console | Font used for the debugging console.
web-family-standard | Font family for standard fonts.
web-family-fixed | Font family for fixed fonts.
web-family-serif | Font family for serif fonts.
web-family-sans-serif | Font family for sans-serif fonts.
web-family-cursive | Font family for cursive fonts.
web-family-fantasy | Font family for fantasy fonts.
web-size-minimum | The hard minimum font size.
web-size-minimum-logical | The minimum logical font size that is applied when zooming out.
web-size-default | The default font size for regular text.
web-size-default-fixed | The default font size for fixed-pitch text.
keyhint | Font used in the keyhint widget.

## general

General/miscellaneous options.

### ignore-case

Whether to find text on a page case-insensitively.

Valid values:

- `true`: Search case-insensitively

- `false`: Search case-sensitively

- `smart`: Search case-sensitively if there are capital chars

Default: `smart`

### startpage

The default page(s) to open at the start, separated by commas.

Default: `https://duckduckgo.com`

### default-page

The page to open if :open -t/-b/-w is used without URL. Use `about:blank` for a blank page.

Default: `${startpage}`

### auto-search

Whether to start a search when something else than a URL is entered.

Valid values:

- `naive`: Use simple/naive check.

- `dns`: Use DNS requests (might be slow!).

- `false`: Never search automatically.

Default: `naive`

### auto-save-config

Whether to save the config automatically on quit.

Valid values:

- `true`

- `false`

Default: `true`

### auto-save-interval

How often (in milliseconds) to auto-save config/cookies/etc.

Default: `15000`

### editor

The editor (and arguments) to use for the `open-editor` command.

The arguments get split like in a shell, so you can use `"` or `'` to quote them. `{}` gets replaced by the filename of the file to be edited.

Default: `gvim -f "{}"`

### editor-encoding

Encoding to use for editor.

Default: `utf-8`

### private-browsing

Do not record visited pages in the history or store web page icons.

Valid values:

- `true`

- `false`

Default: `false`

### developer-extras

Enable extra tools for Web developers.

This needs to be enabled for `:inspector` to work and also adds an Inspect entry to the context menu.

Valid values:

- `true`

- `false`

Default: `false`

### print-element-backgrounds

Whether the background color and images are also drawn when the page is printed.

Valid values:

- `true`

- `false`

Default: `true`

### xss-auditing

Whether load requests should be monitored for cross-site scripting attempts.

Suspicious scripts will be blocked and reported in the inspector’s JavaScript console. Enabling this feature might have an impact on performance.

Valid values:

- `true`

- `false`

Default: `false`

### site-specific-quirks

Enable workarounds for broken sites.

Valid values:

- `true`

- `false`

Default: `true`

### default-encoding

Default encoding to use for websites.

The encoding must be a string describing an encoding such as utf-8, iso-8859-1, etc. If left empty a default value will be used.

Default: empty

### new-instance-open-target

How to open links in an existing instance if a new one is launched.

Valid values:

- `tab`: Open a new tab in the existing window and activate the window.

- `tab-bg`: Open a new background tab in the existing window and activate the window.

- `tab-silent`: Open a new tab in the existing window without activating the window.

- `tab-bg-silent`: Open a new background tab in the existing window without activating the window.

- `window`: Open in a new window.

Default: `tab`

### log-javascript-console

How to log javascript console messages.

Valid values:

- `none`: Don’t log messages.

- `debug`: Log messages with debug level.

- `info`: Log messages with info level.

Default: `debug`

### save-session

Whether to always save the open pages.

Valid values:

- `true`

- `false`

Default: `false`

### session-default-name

The name of the session to save by default, or empty for the last loaded session.

Default: empty

### url-incdec-segments

The URL segments where `:navigate increment/decrement` will search for a number.

Valid values:

- `host`

- `path`

- `query`

- `anchor`

Default: `path,query`

## ui

General options related to the user interface.

### zoom-levels

The available zoom levels, separated by commas.

Default: `25%,33%,50%,67%,75%,90%,100%,110%,125%,150%,175%,200%,250%,300%,400%,500%`

### default-zoom

The default zoom level.

Default: `100%`

### downloads-position

Where to show the downloaded files.

Valid values:

- `top`

- `bottom`

Default: `top`

### status-position

The position of the status bar.

Valid values:

- `top`

- `bottom`

Default: `bottom`

### message-timeout

Time (in ms) to show messages in the statusbar for.

Default: `2000`

### message-unfocused

Whether to show messages in unfocused windows.

Valid values:

- `true`

- `false`

Default: `false`

### confirm-quit

Whether to confirm quitting the application.

Valid values:

- `always`: Always show a confirmation.

- `multiple-tabs`: Show a confirmation if multiple tabs are opened.

- `downloads`: Show a confirmation if downloads are running

- `never`: Never show a confirmation.

Default: `never`

### zoom-text-only

Whether the zoom factor on a frame applies only to the text or to all content.

Valid values:

- `true`

- `false`

Default: `false`

### frame-flattening

Whether to expand each subframe to its contents.

This will flatten all the frames to become one scrollable page.

Valid values:

- `true`

- `false`

Default: `false`

### user-stylesheet

User stylesheet to use (absolute filename, filename relative to the config directory or CSS string). Will expand environment variables.

Default: `::-webkit-scrollbar { width: 0px; height: 0px; }`

### css-media-type

Set the CSS media type.

Default: empty

### smooth-scrolling

Whether to enable smooth scrolling for webpages.

Valid values:

- `true`

- `false`

Default: `false`

### remove-finished-downloads

Number of milliseconds to wait before removing finished downloads. Will not be removed if value is -1.

Default: `-1`

### hide-statusbar

Whether to hide the statusbar unless a message is shown.

Valid values:

- `true`

- `false`

Default: `false`

### statusbar-padding

Padding for statusbar (top, bottom, left, right).

Default: `1,1,0,0`

### window-title-format

The format to use for the window title. The following placeholders are defined:

- `{perc}`: The percentage as a string like `[10%]`.

- `{perc_raw}`: The raw percentage, e.g. `10`

- `{title}`: The title of the current web page

- `{title_sep}`: The string ` - ` if a title is set, empty otherwise.

- `{id}`: The internal window ID of this window.

- `{scroll_pos}`: The page scroll position.

- `{host}`: The host of the current web page.

Default: `{perc}{title}{title_sep}qutebrowser`

### hide-mouse-cursor

Whether to hide the mouse cursor.

Valid values:

- `true`

- `false`

Default: `false`

### modal-js-dialog

Use standard JavaScript modal dialog for alert() and confirm()

Valid values:

- `true`

- `false`

Default: `false`

### hide-wayland-decoration

Hide the window decoration when using wayland (requires restart)

Valid values:

- `true`

- `false`

Default: `false`

### keyhint-blacklist

Keychains that shouldn’t be shown in the keyhint dialog

Globs are supported, so ;* will blacklist all keychainsstarting with ;. Use * to disable keyhints

Default: empty

## network

Settings related to the network.

### do-not-track

Value to send in the `DNT` header.

Valid values:

- `true`

- `false`

Default: `true`

### accept-language

Value to send in the `accept-language` header.

Default: `en-US,en`

### referer-header

Send the Referer header

Valid values:

- `always`: Always send.

- `never`: Never send; this is not recommended, as some sites may break.

- `same-domain`: Only send for the same domain. This will still protect your privacy, but shouldn’t break any sites.

Default: `same-domain`

### user-agent

User agent to send. Empty to send the default.

Default: empty

### proxy

The proxy to use.

In addition to the listed values, you can use a `socks://...` or `http://...` URL.

Valid values:

- `system`: Use the system wide proxy.

- `none`: Don’t use any proxy

Default: `system`

### proxy-dns-requests

Whether to send DNS requests over the configured proxy.

Valid values:

- `true`

- `false`

Default: `true`

### ssl-strict

Whether to validate SSL handshakes.

Valid values:

- `true`

- `false`

- `ask`

Default: `ask`

### dns-prefetch

Whether to try to pre-fetch DNS entries to speed up browsing.

Valid values:

- `true`

- `false`

Default: `true`

### custom-headers

Set custom headers for qutebrowser HTTP requests.

Default: empty

## completion

Options related to completion and command history.

### auto-open

Automatically open completion when typing.

Valid values:

- `true`

- `false`

Default: `true`

### download-path-suggestion

What to display in the download filename input.

Valid values:

- `path`: Show only the download path.

- `filename`: Show only download filename.

- `both`: Show download path and filename.

Default: `path`

### timestamp-format

How to format timestamps (e.g. for history)

Default: `%Y-%m-%d`

### show

Whether to show the autocompletion window.

Valid values:

- `true`

- `false`

Default: `true`

### height

The height of the completion, in px or as percentage of the window.

Default: `50%`

### cmd-history-max-items

How many commands to save in the command history.

0: no history / -1: unlimited

Default: `100`

### web-history-max-items

How many URLs to show in the web history.

0: no history / -1: unlimited

Default: `1000`

### quick-complete

Whether to move on to the next part when there’s only one possible completion left.

Valid values:

- `true`

- `false`

Default: `true`

### shrink

Whether to shrink the completion to be smaller than the configured size if there are no scrollbars.

Valid values:

- `true`

- `false`

Default: `false`

### scrollbar-width

Width of the scrollbar in the completion window (in px).

Default: `12`

### scrollbar-padding

Padding of scrollbar handle in completion window (in px).

Default: `2`

## input

Options related to input modes.

### timeout

Timeout for ambiguous key bindings.

If the current input forms both a complete match and a partial match, the complete match will be executed after this time.

Default: `500`

### partial-timeout

Timeout for partially typed key bindings.

If the current input forms only partial matches, the keystring will be cleared after this time.

Default: `5000`

### insert-mode-on-plugins

Whether to switch to insert mode when clicking flash and other plugins.

Valid values:

- `true`

- `false`

Default: `false`

### auto-leave-insert-mode

Whether to leave insert mode if a non-editable element is clicked.

Valid values:

- `true`

- `false`

Default: `true`

### auto-insert-mode

Whether to automatically enter insert mode if an editable element is focused after page load.

Valid values:

- `true`

- `false`

Default: `false`

### forward-unbound-keys

Whether to forward unbound keys to the webview in normal mode.

Valid values:

- `all`: Forward all unbound keys.

- `auto`: Forward unbound non-alphanumeric keys.

- `none`: Don’t forward any keys.

Default: `auto`

### spatial-navigation

Enables or disables the Spatial Navigation feature.

Spatial navigation consists in the ability to navigate between focusable elements in a Web page, such as hyperlinks and form controls, by using Left, Right, Up and Down arrow keys. For example, if a user presses the Right key, heuristics determine whether there is an element he might be trying to reach towards the right and which element he probably wants.

Valid values:

- `true`

- `false`

Default: `false`

### links-included-in-focus-chain

Whether hyperlinks should be included in the keyboard focus chain.

Valid values:

- `true`

- `false`

Default: `true`

### rocker-gestures

Whether to enable Opera-like mouse rocker gestures. This disables the context menu.

Valid values:

- `true`

- `false`

Default: `false`

### mouse-zoom-divider

How much to divide the mouse wheel movements to translate them into zoom increments.

Default: `512`

## tabs

Configuration of the tab bar.

### background-tabs

Whether to open new tabs (middleclick/ctrl+click) in background.

Valid values:

- `true`

- `false`

Default: `false`

### select-on-remove

Which tab to select when the focused tab is removed.

Valid values:

- `left`: Select the tab on the left.

- `right`: Select the tab on the right.

- `previous`: Select the previously selected tab.

Default: `right`

### new-tab-position

How new tabs are positioned.

Valid values:

- `left`: On the left of the current tab.

- `right`: On the right of the current tab.

- `first`: At the left end.

- `last`: At the right end.

Default: `right`

### new-tab-position-explicit

How new tabs opened explicitly are positioned.

Valid values:

- `left`: On the left of the current tab.

- `right`: On the right of the current tab.

- `first`: At the left end.

- `last`: At the right end.

Default: `last`

### last-close

Behavior when the last tab is closed.

Valid values:

- `ignore`: Don’t do anything.

- `blank`: Load a blank page.

- `startpage`: Load the start page.

- `default-page`: Load the default page.

- `close`: Close the window.

Default: `ignore`

### show

When to show the tab bar

Valid values:

- `always`: Always show the tab bar.

- `never`: Always hide the tab bar.

- `multiple`: Hide the tab bar if only one tab is open.

- `switching`: Show the tab bar when switching tabs.

Default: `always`

### show-switching-delay

Time to show the tab bar before hiding it when tabs→show is set to switching.

Default: `800`

### wrap

Whether to wrap when changing tabs.

Valid values:

- `true`

- `false`

Default: `true`

### movable

Whether tabs should be movable.

Valid values:

- `true`

- `false`

Default: `true`

### close-mouse-button

On which mouse button to close tabs.

Valid values:

- `right`: Close tabs on right-click.

- `middle`: Close tabs on middle-click.

- `none`: Don’t close tabs using the mouse.

Default: `middle`

### position

The position of the tab bar.

Valid values:

- `top`

- `bottom`

- `left`

- `right`

Default: `top`

### show-favicons

Whether to show favicons in the tab bar.

Valid values:

- `true`

- `false`

Default: `true`

### width

The width of the tab bar if it’s vertical, in px or as percentage of the window.

Default: `20%`

### indicator-width

Width of the progress indicator (0 to disable).

Default: `3`

### tabs-are-windows

Whether to open windows instead of tabs.

Valid values:

- `true`

- `false`

Default: `false`

### title-format

The format to use for the tab title. The following placeholders are defined:

- `{perc}`: The percentage as a string like `[10%]`.

- `{perc_raw}`: The raw percentage, e.g. `10`

- `{title}`: The title of the current web page

- `{title_sep}`: The string ` - ` if a title is set, empty otherwise.

- `{index}`: The index of this tab.

- `{id}`: The internal tab ID of this tab.

- `{scroll_pos}`: The page scroll position.

- `{host}`: The host of the current web page.

Default: `{index}: {title}`

### title-alignment

Alignment of the text inside of tabs

Valid values:

- `left`

- `right`

- `center`

Default: `left`

### mousewheel-tab-switching

Switch between tabs using the mouse wheel.

Valid values:

- `true`

- `false`

Default: `true`

### padding

Padding for tabs (top, bottom, left, right).

Default: `0,0,5,5`

### indicator-padding

Padding for indicators (top, bottom, left, right).

Default: `2,2,0,4`

## storage

Settings related to cache and storage.

### download-directory

The directory to save downloads to. An empty value selects a sensible os-specific default. Will expand environment variables.

Default: empty

### prompt-download-directory

Whether to prompt the user for the download location. If set to false, download-directory will be used.

Valid values:

- `true`

- `false`

Default: `true`

### remember-download-directory

Whether to remember the last used download directory.

Valid values:

- `true`

- `false`

Default: `true`

### maximum-pages-in-cache

The maximum number of pages to hold in the global memory page cache.

The Page Cache allows for a nicer user experience when navigating forth or back to pages in the forward/back history, by pausing and resuming up to n pages.

For more information about the feature, please refer to: http://webkit.org/blog/427/webkit-page-cache-i-the-basics/

Default: empty

### object-cache-capacities

The capacities for the global memory cache for dead objects such as stylesheets or scripts. Syntax: cacheMinDeadCapacity, cacheMaxDead, totalCapacity.

The cacheMinDeadCapacity specifies the minimum number of bytes that dead objects should consume when the cache is under pressure.

cacheMaxDead is the maximum number of bytes that dead objects should consume when the cache is not under pressure.

totalCapacity specifies the maximum number of bytes that the cache should consume overall.

Default: empty

### offline-storage-default-quota

Default quota for new offline storage databases.

Default: empty

### offline-web-application-cache-quota

Quota for the offline web application cache.

Default: empty

### offline-storage-database

Whether support for the HTML 5 offline storage feature is enabled.

Valid values:

- `true`

- `false`

Default: `true`

### offline-web-application-storage

Whether support for the HTML 5 web application cache feature is enabled.

An application cache acts like an HTTP cache in some sense. For documents that use the application cache via JavaScript, the loader engine will first ask the application cache for the contents, before hitting the network.

The feature is described in details at: http://dev.w3.org/html5/spec/Overview.html#appcache

Valid values:

- `true`

- `false`

Default: `true`

### local-storage

Whether support for the HTML 5 local storage feature is enabled.

Valid values:

- `true`

- `false`

Default: `true`

### cache-size

Size of the HTTP network cache.

Default: `52428800`

## content

Loaded plugins/scripts and allowed actions.

### allow-images

Whether images are automatically loaded in web pages.

Valid values:

- `true`

- `false`

Default: `true`

### allow-javascript

Enables or disables the running of JavaScript programs.

Valid values:

- `true`

- `false`

Default: `true`

### allow-plugins

Enables or disables plugins in Web pages.

Qt plugins with a mimetype such as "application/x-qt-plugin" are not affected by this setting.

Valid values:

- `true`

- `false`

Default: `false`

### webgl

Enables or disables WebGL.

Valid values:

- `true`

- `false`

Default: `false`

### css-regions

Enable or disable support for CSS regions.

Valid values:

- `true`

- `false`

Default: `true`

### hyperlink-auditing

Enable or disable hyperlink auditing (<a ping>).

Valid values:

- `true`

- `false`

Default: `false`

### geolocation

Allow websites to request geolocations.

Valid values:

- `true`

- `false`

- `ask`

Default: `ask`

### notifications

Allow websites to show notifications.

Valid values:

- `true`

- `false`

- `ask`

Default: `ask`

### javascript-can-open-windows

Whether JavaScript programs can open new windows.

Valid values:

- `true`

- `false`

Default: `false`

### javascript-can-close-windows

Whether JavaScript programs can close windows.

Valid values:

- `true`

- `false`

Default: `false`

### javascript-can-access-clipboard

Whether JavaScript programs can read or write to the clipboard.

Valid values:

- `true`

- `false`

Default: `false`

### ignore-javascript-prompt

Whether all javascript prompts should be ignored.

Valid values:

- `true`

- `false`

Default: `false`

### ignore-javascript-alert

Whether all javascript alerts should be ignored.

Valid values:

- `true`

- `false`

Default: `false`

### local-content-can-access-remote-urls

Whether locally loaded documents are allowed to access remote urls.

Valid values:

- `true`

- `false`

Default: `false`

### local-content-can-access-file-urls

Whether locally loaded documents are allowed to access other local urls.

Valid values:

- `true`

- `false`

Default: `true`

### cookies-accept

Control which cookies to accept.

Valid values:

- `all`: Accept all cookies.

- `no-3rdparty`: Accept cookies from the same origin only.

- `no-unknown-3rdparty`: Accept cookies from the same origin only, unless a cookie is already set for the domain.

- `never`: Don’t accept cookies at all.

Default: `no-3rdparty`

### cookies-store

Whether to store cookies.

Valid values:

- `true`

- `false`

Default: `true`

### host-block-lists

List of URLs of lists which contain hosts to block.

The file can be in one of the following formats:

- An /etc/hosts-like file

- One host per line

- A zip-file of any of the above, with either only one file, or a file named hosts (with any extension).

Default: `http://www.malwaredomainlist.com/hostslist/hosts.txt,http://someonewhocares.org/hosts/hosts,http://winhelp2002.mvps.org/hosts.zip,http://malwaredomains.lehigh.edu/files/justdomains.zip,http://pgl.yoyo.org/adservers/serverlist.php?hostformat=hosts&mimetype=plaintext`

### host-blocking-enabled

Whether host blocking is enabled.

Valid values:

- `true`

- `false`

Default: `true`

### host-blocking-whitelist

List of domains that should always be loaded, despite being ad-blocked.

Domains may contain * and ? wildcards and are otherwise required to exactly match the requested domain.

Local domains are always exempt from hostblocking.

Default: `piwik.org`

### enable-pdfjs

Enable pdf.js to view PDF files in the browser.

Note that the files can still be downloaded by clicking the download button in the pdf.js viewer.

Valid values:

- `true`

- `false`

Default: `false`

## hints

Hinting settings.

### border

CSS border value for hints.

Default: `1px solid #E3BE23`

### opacity

Opacity for hints.

Default: `0.7`

### mode

Mode to use for hints.

Valid values:

- `number`: Use numeric hints.

- `letter`: Use the chars in the hints → chars setting.

- `word`: Use hints words based on the html elements and the extra words.

Default: `letter`

### chars

Chars used for hint strings.

Default: `asdfghjkl`

### min-chars

Minimum number of chars used for hint strings.

Default: `1`

### scatter

Whether to scatter hint key chains (like Vimium) or not (like dwb). Ignored for number hints.

Valid values:

- `true`

- `false`

Default: `true`

### uppercase

Make chars in hint strings uppercase.

Valid values:

- `true`

- `false`

Default: `false`

### dictionary

The dictionary file to be used by the word hints.

Default: `/usr/share/dict/words`

### auto-follow

Follow a hint immediately when the hint text is completely matched.

Valid values:

- `true`

- `false`

Default: `true`

### auto-follow-timeout

A timeout to inhibit normal-mode key bindings after a successfulauto-follow.

Default: `0`

### next-regexes

A comma-separated list of regexes to use for next links.

Default: `\bnext\b,\bmore\b,\bnewer\b,\b[>→≫\b,\b(>>|»)\b,\bcontinue\b]`

### prev-regexes

A comma-separated list of regexes to use for prev links.

Default: `\bprev(ious)?\b,\bback\b,\bolder\b,\b[<←≪\b,\b(<<|«)\b]`

### find-implementation

Which implementation to use to find elements to hint.

Valid values:

- `javascript`: Better but slower

- `python`: Slightly worse but faster

Default: `javascript`

## searchengines

Definitions of search engines which can be used via the address bar. The searchengine named `DEFAULT` is used when `general -> auto-search` is true and something else than a URL was entered to be opened. Other search engines can be used by prepending the search engine name to the search term, e.g. `:open google qutebrowser`. The string `{}` will be replaced by the search term, use `{{` and `}}` for literal `{`/`}` signs.

## aliases

Aliases for commands. By default, no aliases are defined. Example which adds a new command `:qtb` to open qutebrowsers website:

`qtb = open http://www.qutebrowser.org/`

## colors

Colors used in the UI. A value can be in one of the following format:

- `#RGB`/`#RRGGBB`/`#RRRGGGBBB`/`#RRRRGGGGBBBB`

- An SVG color name as specified in the W3C specification.

- transparent (no color)

- `rgb(r, g, b)` / `rgba(r, g, b, a)` (values 0-255 or percentages)

- `hsv(h, s, v)` / `hsva(h, s, v, a)` (values 0-255, hue 0-359)

- A gradient as explained in the Qt documentation under “Gradient”.

A *.system value determines the color system to use for color interpolation between similarly-named *.start and *.stop entries, regardless of how they are defined in the options. Valid values are rgb, hsv, and hsl.

The `hints.*` values are a special case as they’re real CSS colors, not Qt-CSS colors. There, for a gradient, you need to use `-webkit-gradient`, see the WebKit documentation.

### completion.fg

Text color of the completion widget.

Default: `white`

### completion.bg

Background color of the completion widget.

Default: `#333333`

### completion.alternate-bg

Alternating background color of the completion widget.

Default: `#444444`

### completion.category.fg

Foreground color of completion widget category headers.

Default: `white`

### completion.category.bg

Background color of the completion widget category headers.

Default: `qlineargradient(x1:0, y1:0, x2:0, y2:1, stop:0 #888888, stop:1 #505050)`

### completion.category.border.top

Top border color of the completion widget category headers.

Default: `black`

### completion.category.border.bottom

Bottom border color of the completion widget category headers.

Default: `${completion.category.border.top}`

### completion.item.selected.fg

Foreground color of the selected completion item.

Default: `black`

### completion.item.selected.bg

Background color of the selected completion item.

Default: `#e8c000`

### completion.item.selected.border.top

Top border color of the completion widget category headers.

Default: `#bbbb00`

### completion.item.selected.border.bottom

Bottom border color of the selected completion item.

Default: `${completion.item.selected.border.top}`

### completion.match.fg

Foreground color of the matched text in the completion.

Default: `#ff4444`

### completion.scrollbar.fg

Color of the scrollbar handle in completion view.

Default: `${completion.fg}`

### completion.scrollbar.bg

Color of the scrollbar in completion view

Default: `${completion.bg}`

### statusbar.fg

Foreground color of the statusbar.

Default: `white`

### statusbar.bg

Background color of the statusbar.

Default: `black`

### statusbar.fg.error

Foreground color of the statusbar if there was an error.

Default: `${statusbar.fg}`

### statusbar.bg.error

Background color of the statusbar if there was an error.

Default: `red`

### statusbar.fg.warning

Foreground color of the statusbar if there is a warning.

Default: `${statusbar.fg}`

### statusbar.bg.warning

Background color of the statusbar if there is a warning.

Default: `darkorange`

### statusbar.fg.prompt

Foreground color of the statusbar if there is a prompt.

Default: `${statusbar.fg}`

### statusbar.bg.prompt

Background color of the statusbar if there is a prompt.

Default: `darkblue`

### statusbar.fg.insert

Foreground color of the statusbar in insert mode.

Default: `${statusbar.fg}`

### statusbar.bg.insert

Background color of the statusbar in insert mode.

Default: `darkgreen`

### statusbar.fg.command

Foreground color of the statusbar in command mode.

Default: `${statusbar.fg}`

### statusbar.bg.command

Background color of the statusbar in command mode.

Default: `${statusbar.bg}`

### statusbar.fg.caret

Foreground color of the statusbar in caret mode.

Default: `${statusbar.fg}`

### statusbar.bg.caret

Background color of the statusbar in caret mode.

Default: `purple`

### statusbar.fg.caret-selection

Foreground color of the statusbar in caret mode with a selection

Default: `${statusbar.fg}`

### statusbar.bg.caret-selection

Background color of the statusbar in caret mode with a selection

Default: `#a12dff`

### statusbar.progress.bg

Background color of the progress bar.

Default: `white`

### statusbar.url.fg

Default foreground color of the URL in the statusbar.

Default: `${statusbar.fg}`

### statusbar.url.fg.success

Foreground color of the URL in the statusbar on successful load (http).

Default: `white`

### statusbar.url.fg.success.https

Foreground color of the URL in the statusbar on successful load (https).

Default: `lime`

### statusbar.url.fg.error

Foreground color of the URL in the statusbar on error.

Default: `orange`

### statusbar.url.fg.warn

Foreground color of the URL in the statusbar when there’s a warning.

Default: `yellow`

### statusbar.url.fg.hover

Foreground color of the URL in the statusbar for hovered links.

Default: `aqua`

### tabs.fg.odd

Foreground color of unselected odd tabs.

Default: `white`

### tabs.bg.odd

Background color of unselected odd tabs.

Default: `grey`

### tabs.fg.even

Foreground color of unselected even tabs.

Default: `white`

### tabs.bg.even

Background color of unselected even tabs.

Default: `darkgrey`

### tabs.fg.selected.odd

Foreground color of selected odd tabs.

Default: `white`

### tabs.bg.selected.odd

Background color of selected odd tabs.

Default: `black`

### tabs.fg.selected.even

Foreground color of selected even tabs.

Default: `${tabs.fg.selected.odd}`

### tabs.bg.selected.even

Background color of selected even tabs.

Default: `${tabs.bg.selected.odd}`

### tabs.bg.bar

Background color of the tab bar.

Default: `#555555`

### tabs.indicator.start

Color gradient start for the tab indicator.

Default: `#0000aa`

### tabs.indicator.stop

Color gradient end for the tab indicator.

Default: `#00aa00`

### tabs.indicator.error

Color for the tab indicator on errors..

Default: `#ff0000`

### tabs.indicator.system

Color gradient interpolation system for the tab indicator.

Valid values:

- `rgb`: Interpolate in the RGB color system.

- `hsv`: Interpolate in the HSV color system.

- `hsl`: Interpolate in the HSL color system.

- `none`: Don’t show a gradient.

Default: `rgb`

### hints.fg

Font color for hints.

Default: `black`

### hints.bg

Background color for hints.

Default: `-webkit-gradient(linear, left top, left bottom, color-stop(0%,#FFF785), color-stop(100%,#FFC542))`

### hints.fg.match

Font color for the matched part of hints.

Default: `green`

### downloads.bg.bar

Background color for the download bar.

Default: `black`

### downloads.fg.start

Color gradient start for download text.

Default: `white`

### downloads.bg.start

Color gradient start for download backgrounds.

Default: `#0000aa`

### downloads.fg.stop

Color gradient end for download text.

Default: `${downloads.fg.start}`

### downloads.bg.stop

Color gradient stop for download backgrounds.

Default: `#00aa00`

### downloads.fg.system

Color gradient interpolation system for download text.

Valid values:

- `rgb`: Interpolate in the RGB color system.

- `hsv`: Interpolate in the HSV color system.

- `hsl`: Interpolate in the HSL color system.

- `none`: Don’t show a gradient.

Default: `rgb`

### downloads.bg.system

Color gradient interpolation system for download backgrounds.

Valid values:

- `rgb`: Interpolate in the RGB color system.

- `hsv`: Interpolate in the HSV color system.

- `hsl`: Interpolate in the HSL color system.

- `none`: Don’t show a gradient.

Default: `rgb`

### downloads.fg.error

Foreground color for downloads with errors.

Default: `white`

### downloads.bg.error

Background color for downloads with errors.

Default: `red`

### webpage.bg

Background color for webpages if unset (or empty to use the theme’s color)

Default: `white`

### keyhint.fg

Text color for the keyhint widget.

Default: `#FFFFFF`

### keyhint.fg.suffix

Highlight color for keys to complete the current keychain

Default: `#FFFF00`

### keyhint.bg

Background color of the keyhint widget.

Default: `rgba(0, 0, 0, 80%)`

## fonts

Fonts used for the UI, with optional style/weight/size.

- Style: `normal`/`italic`/`oblique`

- Weight: `normal`, `bold`, `100`..`900`

- Size: number `px`/`pt`

### _monospace

Default monospace fonts.

Default: `Terminus, Monospace, "DejaVu Sans Mono", Monaco, "Bitstream Vera Sans Mono", "Andale Mono", "Courier New", Courier, "Liberation Mono", monospace, Fixed, Consolas, Terminal`

### completion

Font used in the completion widget.

Default: `8pt ${_monospace}`

### tabbar

Font used in the tab bar.

Default: `8pt ${_monospace}`

### statusbar

Font used in the statusbar.

Default: `8pt ${_monospace}`

### downloads

Font used for the downloadbar.

Default: `8pt ${_monospace}`

### hints

Font used for the hints.

Default: `bold 13px Monospace`

### debug-console

Font used for the debugging console.

Default: `8pt ${_monospace}`

### web-family-standard

Font family for standard fonts.

Default: empty

### web-family-fixed

Font family for fixed fonts.

Default: empty

### web-family-serif

Font family for serif fonts.

Default: empty

### web-family-sans-serif

Font family for sans-serif fonts.

Default: empty

### web-family-cursive

Font family for cursive fonts.

Default: empty

### web-family-fantasy

Font family for fantasy fonts.

Default: empty

### web-size-minimum

The hard minimum font size.

Default: empty

### web-size-minimum-logical

The minimum logical font size that is applied when zooming out.

Default: empty

### web-size-default

The default font size for regular text.

Default: empty

### web-size-default-fixed

The default font size for fixed-pitch text.

Default: empty

### keyhint

Font used in the keyhint widget.

Default: `8pt ${_monospace}`